"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const danger_mock_1 = require("./danger-mock");
const index_1 = require("./index");
describe("slack()", () => {
    beforeEach(() => {
        global.warn = jest.fn();
        global.message = jest.fn();
        global.fail = jest.fn();
        global.markdown = jest.fn();
    });
    afterEach(() => {
        global.warn = undefined;
        global.message = undefined;
        global.fail = undefined;
        global.markdown = undefined;
    });
});
describe("createMessage()", () => {
    let pr;
    let options;
    let expectedText;
    beforeEach(() => {
        pr = {
            html_url: "custom_url",
            number: 10,
            title: "super PR",
            body: "Some text in body",
            user: {
                login: "julon",
                html_url: "julon_url",
            },
        };
        options = {
            webhookUrl: "url",
            text: "text",
            username: "username",
            iconEmoji: "iconEmoji",
            iconUrl: "iconUrl",
            channel: "#channel",
        };
        expectedText = "<custom_url|*PR#10* - super PR> by <julon_url|julon>\nSome text in body";
    });
    it("should output the correct options (text, username, iconEmoji, iconUrl, channel) when set", () => {
        const result = index_1.createMessage(pr, danger_mock_1.summaryResults, options);
        expect(result.text).toBe(`text`);
        expect(result.username).toBe("username");
        expect(result.iconEmoji).toBe("iconEmoji");
        expect(result.iconUrl).toBe("iconUrl");
        expect(result.channel).toBe("#channel");
    });
    it("should output the report text when no text is set", () => {
        const result = index_1.createMessage(pr, danger_mock_1.summaryResults, { webhookUrl: "" });
        expect(result.text).toBe(expectedText);
    });
    it("should output no attachment and append a message saying nothing to show when results is empty", () => {
        const result = index_1.createMessage(pr, danger_mock_1.emptyResults, { webhookUrl: "" });
        expect(result.text).toBe(`${expectedText}\nNo output to show.`);
    });
    it("should output one fail attachment when results contains a fail", () => {
        const result = index_1.createMessage(pr, danger_mock_1.failsResults, { webhookUrl: "" });
        expect(result.attachments[0]).toEqual({
            color: "danger",
            fallback: "Fails (1)",
            title: "Fails (1)",
            text: "• Failing message",
            mrkdwn_in: ["text"],
        });
    });
});
describe("getDynamicEmoji()", () => {
    it("should return an angry emoji if there is at least a fail", () => {
        const result = index_1.getDynamicEmoji(danger_mock_1.failsResults.fails, danger_mock_1.failsResults.warnings);
        expect(result).toBe(":rage:");
    });
    it("should return an neutral face emoji if there is no fail and at least a warning", () => {
        const result = index_1.getDynamicEmoji(danger_mock_1.warnResults.fails, danger_mock_1.warnResults.warnings);
        expect(result).toBe(":neutral_face:");
    });
    it("should return an happy face emoji if there is no fail and no warning", () => {
        const result = index_1.getDynamicEmoji(danger_mock_1.emptyResults.fails, danger_mock_1.emptyResults.warnings);
        expect(result).toBe(":blush:");
    });
    it("should return an angry emoji if there is at least a fail and some warning", () => {
        const result = index_1.getDynamicEmoji(danger_mock_1.summaryResults.fails, danger_mock_1.summaryResults.warnings);
        expect(result).toBe(":rage:");
    });
});
describe("createAttachment()", () => {
    it("should return an attachment with a title, a black color and one violation", () => {
        const violations = [{ message: "This is a violation" }];
        const result = index_1.createAttachment("title", "#000000", violations);
        expect(result).toEqual({
            color: "#000000",
            fallback: "title (1)",
            title: "title (1)",
            text: "• This is a violation",
            mrkdwn_in: ["text"],
        });
    });
});
describe("createMarkdownAttachment()", () => {
    it("should return an attachment with a title, a black color and one violation", () => {
        const markdowns = ["This is markdown"];
        const result = index_1.createMarkdownAttachment("title", "#000000", markdowns);
        expect(result).toEqual({
            color: "#000000",
            fallback: "title",
            title: "title",
            text: "This is markdown",
            mrkdwn_in: ["text"],
        });
    });
});
